# はじめに

OpenSesameへようこそ! 何かお手伝いできることはありますか?

<table><tr><td>

新規実験の作成:<br />
%(templates)s

</td><td>

%(recent_experiments)s

</td></tr></table>

OpenSesameのサポートをを考えたことはありますか?

[PayPalを通して寄付](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QEWKSAY4WMKRW){: .important-button}

もっと詳しく知る:

[ドキュメンテーショを読む](http://osdoc.cogsci.nl){: .button}<br />
[フォーラムで質問をする](http://forum.cogsci.nl){: .button}<br />
